@@ -1,3 +1,21 @@
+/*
+ *  scout Maemo 5 calendar, contact and conversations search tool
+ *  Copyright (C) 2010 Nicolai Hess
+ *  
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *  
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *  
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
 #include "config.h"
 
 #include <hildon/hildon.h>
@@ -583,7 +601,7 @@ _find_in_text(ScoutWindow* self, const gchar* text0, gchar** prefix, gchar** suf
 {
   gchar* text = NULL;
   const gchar* faulty_char = NULL;
-  if(!g_utf8_validate(text0, -1, &faulty_char))
+  if(text0 == NULL || !g_utf8_validate(text0, -1, &faulty_char))
   {
     /*
     g_warning("text invalid %s %c\n", text0, faulty_char);
@@ -1097,7 +1115,18 @@ _do_search(ScoutWindow* self)
   if(gtk_entry_get_text_length(entry)>0)
   {
     if(self->priv->current_search_text)
-      g_free(self->priv->current_search_text);
+    {
+      if(g_strcmp0(self->priv->current_search_text, gtk_entry_get_text(entry)) == 0)
+      {
+	g_free(self->priv->current_search_text);
+	self->priv->current_search_text = NULL;
+	return;
+      }
+      else
+      {
+	g_free(self->priv->current_search_text);
+      }
+    }
 
     if(!self->priv->search_case_sensitive)
       self->priv->current_search_text = g_utf8_strdown(gtk_entry_get_text(entry), -1);
